@@ -1,15 +1,13 @@
-from typing import Optional, List, Dict, Any
 import sys
 import warnings
 from pathlib import Path
+from typing import Any, Dict, List, Optional
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 import yaml
 from webviz_config.utils import terminal_colors
 
-from .._utils.colors import hex_to_rgba
-
 
 def set_simulation_line_shape_fallback(line_shape_fallback: str) -> str:
     """
@@ -56,13 +54,13 @@ def calc_series_statistics(
     refaxis is used if another column than DATE should be used to groupby.
     """
     # Invert p10 and p90 due to oil industry convention.
-    def p10(x: List[float]) -> List[float]:
+    def p10(x: List[float]) -> np.floating:
         return np.nanpercentile(x, q=90)
 
-    def p90(x: List[float]) -> List[float]:
+    def p90(x: List[float]) -> np.floating:
         return np.nanpercentile(x, q=10)
 
-    def p50(x: List[float]) -> List[float]:
+    def p50(x: List[float]) -> np.floating:
         return np.nanpercentile(x, q=50)
 
     # Calculate statistics, ignoring NaNs.
@@ -86,80 +84,6 @@ def calc_series_statistics(
     return stat_df
 
 
-def add_fanchart_traces(
-    ens_stat_df: pd.DataFrame,
-    vector: str,
-    color: str,
-    legend_group: str,
-    line_shape: str,
-    refaxis: str = "DATE",
-    hovertemplate: str = "(%{x}, %{y})<br>",
-) -> List[Dict[str, Any]]:
-    """Renders a fanchart for an ensemble vector"""
-    fill_color = hex_to_rgba(color, 0.3)
-    line_color = hex_to_rgba(color, 1)
-    return [
-        {
-            "name": legend_group,
-            "hovertemplate": hovertemplate + "Maximum",
-            "x": ens_stat_df[("", refaxis)],
-            "y": ens_stat_df[(vector, "max")],
-            "mode": "lines",
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertemplate": hovertemplate + "P90",
-            "x": ens_stat_df[("", refaxis)],
-            "y": ens_stat_df[(vector, "low_p90")],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertemplate": hovertemplate + "P10",
-            "x": ens_stat_df[("", refaxis)],
-            "y": ens_stat_df[(vector, "high_p10")],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertemplate": hovertemplate + "Mean",
-            "x": ens_stat_df[("", refaxis)],
-            "y": ens_stat_df[(vector, "mean")],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": True,
-        },
-        {
-            "name": legend_group,
-            "hovertemplate": hovertemplate + "Minimum",
-            "x": ens_stat_df[("", refaxis)],
-            "y": ens_stat_df[(vector, "min")],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-    ]
-
-
 def add_statistics_traces(
     ens_stat_df: pd.DataFrame,
     vector: str,
@@ -338,13 +262,13 @@ def check_and_format_observations(obsfile: Path) -> dict:
         except TypeError as exc:
             raise TypeError(
                 "The observation file's othermost level must be a dictionary, while the input "
-                f"file's outermost level is of type {type(obslist)}."
+                f"file's outermost level is of type {type(obsfile_data)}."
             ) from exc
         if not isinstance(obslist, list):
             raise TypeError(
                 "The observation file's smry section must be formatted as a list of dictionaries."
             )
-        observations = dict()
+        observations: dict = {}
 
         # pylint: disable=too-many-nested-blocks
         for item in obslist:
