@@ -29,12 +29,14 @@ from ._horizon_uncertainty_viewer import HorizonUncertaintyViewer
 from ._inplace_volumes import InplaceVolumes
 from ._inplace_volumes_onebyone import InplaceVolumesOneByOne
 from ._line_plotter_fmu.line_plotter_fmu import LinePlotterFMU
+from ._map_viewer_fmu import MapViewerFMU
 from ._morris_plot import MorrisPlot
 from ._parameter_analysis import ParameterAnalysis
 from ._parameter_correlation import ParameterCorrelation
 from ._parameter_distribution import ParameterDistribution
 from ._parameter_parallel_coordinates import ParameterParallelCoordinates
 from ._parameter_response_correlation import ParameterResponseCorrelation
+from ._prod_misfit import ProdMisfit
 from ._property_statistics import PropertyStatistics
 from ._pvt_plot import PvtPlot
 from ._relative_permeability import RelativePermeability
@@ -45,17 +47,20 @@ from ._reservoir_simulation_timeseries_onebyone import (
 from ._reservoir_simulation_timeseries_regional import (
     ReservoirSimulationTimeSeriesRegional,
 )
-from ._rft_plotter.rft_plotter import RftPlotter
+from ._rft_plotter import RftPlotter
 from ._running_time_analysis_fmu import RunningTimeAnalysisFMU
 from ._segy_viewer import SegyViewer
 from ._seismic_misfit import SeismicMisfit
+from ._simulation_time_series import SimulationTimeSeries
 from ._structural_uncertainty import StructuralUncertainty
 from ._subsurface_map import SubsurfaceMap
 from ._surface_viewer_fmu import SurfaceViewerFMU
 from ._surface_with_grid_cross_section import SurfaceWithGridCrossSection
 from ._surface_with_seismic_cross_section import SurfaceWithSeismicCrossSection
+from ._swatinit_qc import SwatinitQC
 from ._tornado_plotter_fmu import TornadoPlotterFMU
 from ._volumetric_analysis import VolumetricAnalysis
+from ._well_analysis import WellAnalysis
 from ._well_completions import WellCompletions
 from ._well_cross_section import WellCrossSection
 from ._well_cross_section_fmu import WellCrossSectionFMU
