@@ -1,16 +1,12 @@
-from typing import List, Dict, Tuple, Callable
-from uuid import uuid4
 from pathlib import Path
+from typing import Callable, Dict, List, Tuple
+from uuid import uuid4
 
 import pandas as pd
-import dash
-from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State
-import dash_html_components as html
-import dash_core_components as dcc
 import webviz_subsurface_components as wsc
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from dash import Dash, Input, Output, State, callback_context, dcc, html
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
@@ -45,7 +41,7 @@ and the parameter columns.
 
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile: Path = None,
         ensembles: list = None,
@@ -170,7 +166,7 @@ and the parameter columns.
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.ids("parameter"), "value"),
             [
@@ -183,7 +179,7 @@ and the parameter columns.
             _prev_click: int, _next_click: int, column: str
         ) -> str:
 
-            ctx = dash.callback_context.triggered
+            ctx = callback_context.triggered
             if ctx is None:
                 raise PreventUpdate
             callback = ctx[0]["prop_id"]
