@@ -1,4 +1,5 @@
 from pathlib import Path
+from typing import Any, Callable, Dict, List, Tuple
 
 import pandas as pd
 import webviz_core_components as wcc
@@ -10,12 +11,16 @@ from webviz_config.utils import calculate_slider_step
 from webviz_config.webviz_store import webvizstore
 
 import webviz_subsurface._utils.parameter_response as parresp
-from webviz_subsurface._datainput.fmu_input import load_csv, load_parameters
+from webviz_subsurface._datainput.fmu_input import load_csv
 from webviz_subsurface._figures import create_figure
-from webviz_subsurface._models import (
-    EnsembleSetModel,
-    ParametersModel,
-    caching_ensemble_set_model_factory,
+from webviz_subsurface._models import ParametersModel
+from webviz_subsurface._providers import (
+    EnsembleSummaryProvider,
+    EnsembleSummaryProviderFactory,
+    EnsembleTableProviderFactory,
+    EnsembleTableProviderSet,
+    Frequency,
+    get_matching_vector_names,
 )
 
 
@@ -23,7 +28,7 @@ class ParameterResponseCorrelation(WebvizPluginABC):
     """Visualizes correlations between numerical input parameters and responses.
 
 ---
-**Three main options for input data: Aggregated, file per realization and read from UNSMRY.**
+**Three main options for input data: Aggregated, file per realization and read from `.arrow`.**
 
 **Using aggregated data**
 * **`parameter_csv`:** Aggregated csvfile for input parameters with `REAL` and `ENSEMBLE` columns \
@@ -40,15 +45,15 @@ columns (absolute path or relative to config file).
 
 **Using simulation time series data directly from `UNSMRY` files as responses**
 * **`ensembles`:** Which ensembles in `shared_settings` to visualize. The lack of `response_file` \
-                implies that the input data should be time series data from simulation `.UNSMRY` \
-                files, read using `fmu-ensemble`.
+                implies that the input data should be time series data from `.arrow` file \
+* **`rel_file_pattern`:** Relative file path to `.arrow` file.
 * **`column_keys`:** (Optional) slist of simulation vectors to include as responses when reading \
                 from UNSMRY-files in the defined ensembles (default is all vectors). * can be \
                 used as wild card.
 * **`sampling`:** (Optional) sampling frequency when reading simulation data directly from \
                `.UNSMRY`-files (default is monthly).
 
-?> The `UNSMRY` input method implies that the "DATE" vector will be used as a filter \
+?> The `.arrow` input method implies that the "DATE" vector will be used as a filter \
    of type `single` (as defined below under `response_filters`).
 
 
@@ -66,8 +71,8 @@ All of these are optional, some have defaults seen in the code snippet below.
                       (cannot use with response_include).
 * **`response_include`:** List of response (columns in csv or simulation vectors) to include \
                        (cannot use with response_ignore).
-* **`aggregation`:** How to aggregate responses per realization. Either `sum` or `mean`.
-* **`corr_method`:** Correlation method. Either `pearson` or `spearman`.
+* **`aggregation`:** Initial way to aggregate responses per realization. Either `sum` or `mean`.
+* **`corr_method`:** Initial correlation method. Either `pearson` or `spearman`.
 
 ---
 
@@ -83,7 +88,7 @@ would make more sense (though the pressures in this case would not be volume wei
 and the aggregation would therefore likely be imprecise).
 
 !> It is **strongly recommended** to keep the data frequency to a regular frequency (like \
-`monthly` or `yearly`). This applies to both csv input and when reading from `UNSMRY` \
+`monthly` or `yearly`). This applies to both csv input and when reading from `.arrow` \
 (controlled by the `sampling` key). This is because the statistics are calculated per DATE over \
 all realizations in an ensemble, and the available dates should therefore not differ between \
 individual realizations of an ensemble.
@@ -105,17 +110,12 @@ The `response_file` must have the response columns (and the columns to use as `r
 if that option is used).
 
 
-**Using simulation time series data directly from `UNSMRY` files as responses**
+**Using simulation time series data directly from `.arrow` files as responses**
 
 Parameters are extracted automatically from the `parameters.txt` files in the individual
-realizations, using the `fmu-ensemble` library.
+realizations.
 
-Responses are extracted automatically from the `UNSMRY` files in the individual realizations,
-using the `fmu-ensemble` library.
-
-!> The `UNSMRY` files are auto-detected by `fmu-ensemble` in the `eclipse/model` folder of the \
-individual realizations. You should therefore not have more than one `UNSMRY` file in this \
-folder, to avoid risk of not extracting the right data.
+Responses are extracted automatically from the `.arrow` files in the individual realizations.
 """
 
     # pylint:disable=too-many-arguments, too-many-locals
@@ -126,6 +126,7 @@ folder, to avoid risk of not extracting the right data.
         parameter_csv: Path = None,
         response_csv: Path = None,
         ensembles: list = None,
+        rel_file_pattern: str = "share/results/unsmry/*.arrow",
         response_file: str = None,
         response_filters: dict = None,
         response_ignore: list = None,
@@ -143,7 +144,7 @@ folder, to avoid risk of not extracting the right data.
         self.response_file = response_file if response_file else None
         self.response_filters = response_filters if response_filters else {}
         self.column_keys = column_keys
-        self.time_index = sampling
+        self._sampling = Frequency(sampling)
         self.corr_method = corr_method
         self.aggregation = aggregation
         if response_ignore and response_include:
@@ -165,8 +166,11 @@ folder, to avoid risk of not extracting the right data.
                 ens: webviz_settings.shared_settings["scratch_ensembles"][ens]
                 for ens in ensembles
             }
-            parameterdf = load_parameters(
-                ensemble_paths=self.ens_paths, ensemble_set_name="EnsembleSet"
+            table_provider_factory = EnsembleTableProviderFactory.instance()
+            parameterdf = create_df_from_table_provider(
+                table_provider_factory.create_provider_set_from_per_realization_parameter_file(
+                    self.ens_paths
+                )
             )
             if self.response_file:
                 self.responsedf = load_csv(
@@ -175,15 +179,18 @@ folder, to avoid risk of not extracting the right data.
                     ensemble_set_name="EnsembleSet",
                 )
             else:
-                self.emodel: EnsembleSetModel = (
-                    caching_ensemble_set_model_factory.get_or_create_model(
-                        ensemble_paths=self.ens_paths,
-                        column_keys=self.column_keys,
-                        time_index=self.time_index,
+                smry_provider_factory = EnsembleSummaryProviderFactory.instance()
+                provider_set = {
+                    ens_name: smry_provider_factory.create_from_arrow_unsmry_presampled(
+                        ens_path, rel_file_pattern, self._sampling
                     )
-                )
-                self.responsedf = self.emodel.get_or_load_smry_cached()
+                    for ens_name, ens_path in self.ens_paths.items()
+                }
                 self.response_filters["DATE"] = "single"
+                self.responsedf = create_df_from_summary_provider(
+                    provider_set,
+                    self.column_keys,
+                )
         else:
             raise ValueError(
                 'Incorrect arguments. Either provide "csv files" or "ensembles and response_file".'
@@ -193,6 +200,7 @@ folder, to avoid risk of not extracting the right data.
         )
         self.parameterdf = pmodel.dataframe
         self.parameter_columns = pmodel.parameters
+
         parresp.check_runs(self.parameterdf, self.responsedf)
         parresp.check_response_filters(self.responsedf, self.response_filters)
 
@@ -208,7 +216,7 @@ folder, to avoid risk of not extracting the right data.
         self.set_callbacks(app)
 
     @property
-    def tour_steps(self):
+    def tour_steps(self) -> List[Dict[str, Any]]:
         steps = [
             {
                 "id": self.uuid("layout"),
@@ -229,8 +237,8 @@ folder, to avoid risk of not extracting the right data.
             {
                 "id": self.uuid("distribution-graph"),
                 "content": (
-                    "Visualized the distribution of the response and the selected input parameter "
-                    "in the correlation chart."
+                    "Visualization of the distribution of the response and the selected "
+                    "input parameter in the correlation chart."
                 ),
             },
             {
@@ -241,17 +249,43 @@ folder, to avoid risk of not extracting the right data.
                 "id": self.uuid("responses"),
                 "content": ("Select the active response."),
             },
+            {
+                "id": self.uuid("correlation-method"),
+                "content": ("Select Pearson or Spearman correlation."),
+            },
+            {
+                "id": self.uuid("aggregation"),
+                "content": (
+                    "Select whether the response after filtering should be aggregated "
+                    "by summation or mean."
+                ),
+            },
+            {
+                "id": self.uuid("correlation-cutoff"),
+                "content": (
+                    "Slider to set a minimum correlation factor for parameters shown "
+                    "in plots."
+                ),
+            },
+            {
+                "id": self.uuid("max-params"),
+                "content": ("Slider to set a maximum number of parameters shown"),
+            },
+            {
+                "id": self.uuid("filters"),
+                "content": ("Filters for response and parameters to correlate with."),
+            },
         ]
 
         return steps
 
     @property
-    def ensembles(self):
+    def ensembles(self) -> List[str]:
         """Returns list of ensembles"""
         return list(self.parameterdf["ENSEMBLE"].unique())
 
     @property
-    def filter_layout(self):
+    def filter_layout(self) -> List[Any]:
         """Layout to display selectors for response filters"""
         children = []
         for col_name, col_type in self.response_filters.items():
@@ -259,19 +293,20 @@ folder, to avoid risk of not extracting the right data.
             values = list(self.responsedf[col_name].unique())
             if col_type == "multi":
                 selector = wcc.SelectWithLabel(
-                    label=col_name,
+                    label=f"{col_name}:",
                     id=domid,
                     options=[{"label": val, "value": val} for val in values],
                     value=values,
                     multi=True,
-                    size=min(20, len(values)),
+                    size=min(10, len(values)),
+                    collapsible=True,
                 )
             elif col_type == "single":
                 selector = wcc.Dropdown(
-                    label=col_name,
+                    label=f"{col_name}:",
                     id=domid,
                     options=[{"label": val, "value": val} for val in values],
-                    value=values[0],
+                    value=values[-1],
                     multi=False,
                     clearable=False,
                 )
@@ -281,30 +316,75 @@ folder, to avoid risk of not extracting the right data.
                 return children
             children.append(selector)
 
+        children.append(
+            wcc.SelectWithLabel(
+                label="Parameters:",
+                id=self.uuid("parameter-filter"),
+                options=[
+                    {"label": val, "value": val} for val in self.parameter_columns
+                ],
+                value=self.parameter_columns,
+                multi=True,
+                size=min(10, len(self.parameter_columns)),
+                collapsible=True,
+            )
+        )
+
         return children
 
     @property
-    def control_layout(self):
+    def control_layout(self) -> List[Any]:
         """Layout to select e.g. iteration and response"""
         max_params = len(self.parameter_columns)
         return [
             wcc.Dropdown(
-                label="Ensemble",
+                label="Ensemble:",
                 id=self.uuid("ensemble"),
                 options=[{"label": ens, "value": ens} for ens in self.ensembles],
                 clearable=False,
                 value=self.ensembles[0],
             ),
             wcc.Dropdown(
-                label="Response",
+                label="Response:",
                 id=self.uuid("responses"),
-                options=[{"label": ens, "value": ens} for ens in self.response_columns],
+                options=[{"label": col, "value": col} for col in self.response_columns],
                 clearable=False,
                 value=self.response_columns[0],
             ),
+            wcc.RadioItems(
+                label="Correlation method:",
+                id=self.uuid("correlation-method"),
+                options=[
+                    {"label": opt.capitalize(), "value": opt}
+                    for opt in ["pearson", "spearman"]
+                ],
+                vertical=False,
+                value=self.corr_method,
+            ),
+            wcc.RadioItems(
+                label="Response aggregation:",
+                id=self.uuid("aggregation"),
+                options=[
+                    {"label": opt.capitalize(), "value": opt} for opt in ["sum", "mean"]
+                ],
+                vertical=False,
+                value=self.aggregation,
+            ),
             html.Div(
                 wcc.Slider(
-                    label="Max number of parameters",
+                    label="Correlation cut-off (abs):",
+                    id=self.uuid("correlation-cutoff"),
+                    min=0,
+                    max=1,
+                    step=0.1,
+                    marks={"0": 0, "1": 1},
+                    value=0,
+                ),
+                style={"margin-top": "10px"},
+            ),
+            html.Div(
+                wcc.Slider(
+                    label="Max number of parameters:",
                     id=self.uuid("max-params"),
                     min=1,
                     max=max_params,
@@ -317,7 +397,7 @@ folder, to avoid risk of not extracting the right data.
         ]
 
     @property
-    def layout(self):
+    def layout(self) -> wcc.FlexBox:
         """Main layout"""
         return wcc.FlexBox(
             id=self.uuid("layout"),
@@ -334,7 +414,9 @@ folder, to avoid risk of not extracting the right data.
                         + (
                             [
                                 wcc.Selectors(
-                                    label="Filters", children=self.filter_layout
+                                    label="Filters",
+                                    id=self.uuid("filters"),
+                                    children=self.filter_layout,
                                 )
                             ]
                             if self.response_filters
@@ -375,12 +457,16 @@ folder, to avoid risk of not extracting the right data.
         )
 
     @property
-    def correlation_input_callbacks(self):
+    def correlation_input_callbacks(self) -> List[Input]:
         """List of Inputs for correlation callback"""
         callbacks = [
             Input(self.uuid("ensemble"), "value"),
             Input(self.uuid("responses"), "value"),
             Input(self.uuid("max-params"), "value"),
+            Input(self.uuid("parameter-filter"), "value"),
+            Input(self.uuid("correlation-method"), "value"),
+            Input(self.uuid("aggregation"), "value"),
+            Input(self.uuid("correlation-cutoff"), "value"),
         ]
         if self.response_filters:
             for col_name in self.response_filters:
@@ -388,20 +474,21 @@ folder, to avoid risk of not extracting the right data.
         return callbacks
 
     @property
-    def distribution_input_callbacks(self):
+    def distribution_input_callbacks(self) -> List[Input]:
         """List of Inputs for distribution callback"""
         callbacks = [
             Input(self.uuid("correlation-graph"), "clickData"),
             Input(self.uuid("initial-parameter"), "data"),
             Input(self.uuid("ensemble"), "value"),
             Input(self.uuid("responses"), "value"),
+            Input(self.uuid("aggregation"), "value"),
         ]
         if self.response_filters:
             for col_name in self.response_filters:
                 callbacks.append(Input(self.uuid(f"filter-{col_name}"), "value"))
         return callbacks
 
-    def set_callbacks(self, app):
+    def set_callbacks(self, app) -> None:
         @app.callback(
             [
                 Output(self.uuid("correlation-graph"), "figure"),
@@ -409,7 +496,16 @@ folder, to avoid risk of not extracting the right data.
             ],
             self.correlation_input_callbacks,
         )
-        def _update_correlation_graph(ensemble, response, max_parameters, *filters):
+        def _update_correlation_graph(
+            ensemble: str,
+            response: str,
+            max_parameters: int,
+            selected_parameters: List[str],
+            correlation_method: str,
+            aggregation: str,
+            correlation_cutoff: float,
+            *filters,
+        ):
             """Callback to update correlation graph
 
             1. Filters and aggregates response dataframe per realization
@@ -429,11 +525,14 @@ folder, to avoid risk of not extracting the right data.
                 ensemble,
                 response,
                 filteroptions=filteroptions,
-                aggregation=self.aggregation,
+                aggregation=aggregation,
             )
-            parameterdf = self.parameterdf.loc[self.parameterdf["ENSEMBLE"] == ensemble]
+            parameterdf = self.parameterdf[
+                ["ENSEMBLE", "REAL"] + selected_parameters
+            ].loc[self.parameterdf["ENSEMBLE"] == ensemble]
+
             df = pd.merge(responsedf, parameterdf, on=["REAL"])
-            corrdf = correlate(df, response=response, method=self.corr_method)
+            corrdf = correlate(df, response=response, method=correlation_method)
             try:
                 corr_response = (
                     corrdf[response]
@@ -441,14 +540,19 @@ folder, to avoid risk of not extracting the right data.
                     .drop(["REAL", response], axis=0)
                     .tail(n=max_parameters)
                 )
-
+                corr_response = corr_response[corr_response.abs() >= correlation_cutoff]
                 return (
                     make_correlation_plot(
-                        corr_response, response, self.theme, self.corr_method
+                        corr_response,
+                        response,
+                        self.theme,
+                        correlation_method,
+                        correlation_cutoff,
+                        max_parameters,
                     ),
                     corr_response.index[-1],
                 )
-            except KeyError:
+            except (KeyError, ValueError):
                 return (
                     {
                         "layout": {
@@ -464,7 +568,7 @@ folder, to avoid risk of not extracting the right data.
             self.distribution_input_callbacks,
         )
         def _update_distribution_graph(
-            clickdata, initial_parameter, ensemble, response, *filters
+            clickdata, initial_parameter, ensemble, response, aggregation, *filters
         ):
             """Callback to update distribution graphs.
 
@@ -488,7 +592,7 @@ folder, to avoid risk of not extracting the right data.
                 ensemble,
                 response,
                 filteroptions=filteroptions,
-                aggregation=self.aggregation,
+                aggregation=aggregation,
             )
             parameterdf = self.parameterdf.loc[self.parameterdf["ENSEMBLE"] == ensemble]
             df = pd.merge(responsedf, parameterdf, on=["REAL"])[
@@ -496,7 +600,7 @@ folder, to avoid risk of not extracting the right data.
             ]
             return make_distribution_plot(df, parameter, response, self.theme)
 
-    def add_webvizstore(self):
+    def add_webvizstore(self) -> List[Tuple[Callable, List[Dict]]]:
         if self.parameter_csv and self.response_csv:
             return [
                 (
@@ -516,20 +620,8 @@ folder, to avoid risk of not extracting the right data.
                     ],
                 ),
             ]
-
-        functions = [
-            (
-                load_parameters,
-                [
-                    {
-                        "ensemble_paths": self.ens_paths,
-                        "ensemble_set_name": "EnsembleSet",
-                    }
-                ],
-            ),
-        ]
         if self.response_file:
-            functions.append(
+            return [
                 (
                     load_csv,
                     [
@@ -540,13 +632,11 @@ folder, to avoid risk of not extracting the right data.
                         }
                     ],
                 )
-            )
-        else:
-            functions.extend(self.emodel.webvizstore)
-        return functions
+            ]
+        return []
 
 
-def correlate(inputdf, response, method="pearson"):
+def correlate(inputdf, response, method="pearson") -> pd.DataFrame:
     """Returns the correlation matrix for a dataframe"""
     if method == "pearson":
         corrdf = inputdf.corr(method=method)
@@ -560,14 +650,21 @@ def correlate(inputdf, response, method="pearson"):
     return corrdf.reindex(corrdf[response].abs().sort_values().index)
 
 
-def make_correlation_plot(series, response, theme, corr_method):
+def make_correlation_plot(
+    series, response, theme, corr_method, corr_cutoff, max_parameters
+) -> Dict[str, Any]:
     """Make Plotly trace for correlation plot"""
     xaxis_range = max(abs(series.values)) * 1.1
     layout = {
         "barmode": "relative",
         "margin": {"l": 200, "r": 50, "b": 20, "t": 100},
         "xaxis": {"range": [-xaxis_range, xaxis_range]},
-        "title": f"Correlations ({corr_method}) between {response} and input parameters",
+        "yaxis": {"dtick": 1},
+        "title": (
+            f"Correlations between {response} and input parameters<br>"
+            f"{corr_method.capitalize()} correlation with abs cut-off {corr_cutoff}"
+            f" and max {max_parameters} parameters"
+        ),
     }
     layout = theme.create_themed_layout(layout)
 
@@ -639,11 +736,10 @@ def make_distribution_plot(df, parameter, response, theme):
             },
         )
     )
-
     return fig
 
 
-def make_range_slider(domid, values, col_name):
+def make_range_slider(domid, values, col_name) -> wcc.RangeSlider:
     try:
         values.apply(pd.to_numeric, errors="raise")
     except ValueError as exc:
@@ -652,7 +748,7 @@ def make_range_slider(domid, values, col_name):
             "Ensure that it is a numerical column."
         ) from exc
     return wcc.RangeSlider(
-        label=col_name,
+        label=f"{col_name}:",
         id=domid,
         min=values.min(),
         max=values.max(),
@@ -669,7 +765,7 @@ def make_range_slider(domid, values, col_name):
     )
 
 
-def theme_layout(theme, specific_layout):
+def theme_layout(theme, specific_layout) -> Dict:
     layout = {}
     layout.update(theme["layout"])
     layout.update(specific_layout)
@@ -680,3 +776,35 @@ def theme_layout(theme, specific_layout):
 @webvizstore
 def read_csv(csv_file) -> pd.DataFrame:
     return pd.read_csv(csv_file, index_col=False)
+
+
+def create_df_from_table_provider(provider: EnsembleTableProviderSet) -> pd.DataFrame:
+    """Aggregates parameters from all ensemble into a common dataframe."""
+    dfs = []
+    for ens in provider.ensemble_names():
+        df = provider.ensemble_provider(ens).get_column_data(
+            column_names=provider.ensemble_provider(ens).column_names()
+        )
+        df["ENSEMBLE"] = df.get("ENSEMBLE", ens)
+        dfs.append(df)
+    return pd.concat(dfs)
+
+
+def create_df_from_summary_provider(
+    provider_set: Dict[str, EnsembleSummaryProvider], column_keys: List[str]
+) -> pd.DataFrame:
+    """Aggregates summary data from all ensembles into a common dataframe."""
+    dfs = []
+    for ens_name, provider in provider_set.items():
+        matching_sumvecs = get_matching_vector_names(provider, column_keys)
+        if not matching_sumvecs:
+            raise ValueError(
+                f"No vectors matching the given column_keys: {column_keys} for ensemble: {ens_name}"
+            )
+        df = provider.get_vectors_df(matching_sumvecs, None)
+        df["ENSEMBLE"] = ens_name
+        dfs.append(df)
+
+    df_all = pd.concat(dfs)
+    df_all["DATE"] = pd.to_datetime(df_all["DATE"]).dt.strftime("%Y-%m-%d")
+    return df_all
