@@ -1,26 +1,27 @@
-from typing import Dict, List, Optional, Callable, Union, Tuple
 import json
+from typing import Callable, Dict, List, Optional, Tuple, Union
+
 import numpy as np
 import pandas as pd
 import xtgeo
-import dash
-from dash.dependencies import Input, Output, State, ClientsideFunction
+from dash import ClientsideFunction, Dash, Input, Output, State, callback_context
 from dash.exceptions import PreventUpdate
 
-from webviz_subsurface._models import SurfaceSetModel, WellSetModel
 from webviz_subsurface._components import ColorPicker
+from webviz_subsurface._models import SurfaceSetModel, WellSetModel
 
 from ..figures.intersection import (
-    get_plotly_trace_statistical_surface,
     get_plotly_trace_realization_surface,
+    get_plotly_trace_statistical_surface,
     get_plotly_trace_well_trajectory,
     get_plotly_traces_uncertainty_envelope,
     get_plotly_zonelog_trace,
 )
 
+
 # pylint: disable=too-many-statements
 def update_intersection(
-    app: dash.Dash,
+    app: Dash,
     get_uuid: Callable,
     surface_set_models: Dict[str, SurfaceSetModel],
     well_set_model: WellSetModel,
@@ -124,19 +125,6 @@ def update_intersection(
                 showlegend = True
 
                 if statistics is not None:
-                    if "Uncertainty envelope" in statistics:
-                        envelope_traces = get_plotly_traces_uncertainty_envelope(
-                            surfaceset=surfset,
-                            fence_spec=fence_spec,
-                            legendname=f"{surfacename}({ensemble})",
-                            name=surfacename,
-                            attribute=surfaceattribute,
-                            realizations=realizations,
-                            showlegend=showlegend,
-                            color=color,
-                        )
-                        traces.extend(envelope_traces)
-                        showlegend = False
                     for stat in ["Mean", "Min", "Max"]:
                         if stat in statistics:
                             trace = get_plotly_trace_statistical_surface(
@@ -152,6 +140,19 @@ def update_intersection(
                             )
                             traces.append(trace)
                             showlegend = False
+                    if "Uncertainty envelope" in statistics:
+                        envelope_traces = get_plotly_traces_uncertainty_envelope(
+                            surfaceset=surfset,
+                            fence_spec=fence_spec,
+                            legendname=f"{surfacename}({ensemble})",
+                            name=surfacename,
+                            attribute=surfaceattribute,
+                            realizations=realizations,
+                            showlegend=showlegend,
+                            color=color,
+                        )
+                        traces.extend(envelope_traces)
+                        showlegend = False
                     if "Realizations" in statistics:
                         for real in realizations:
                             trace = get_plotly_trace_realization_surface(
@@ -214,7 +215,7 @@ def update_intersection(
         wellname: str,
     ) -> Dict:
         """Store intersection layout configuration clientside"""
-        ctx = dash.callback_context.triggered[0]
+        ctx = callback_context.triggered[0]
         if "ui_options" in ctx["prop_id"]:
             raise PreventUpdate
 
@@ -358,7 +359,7 @@ def update_intersection(
         zmin: Optional[float],
         zmax: Optional[float],
     ) -> Tuple[Optional[float], Optional[float]]:
-        ctx = dash.callback_context.triggered[0]
+        ctx = callback_context.triggered[0]
         if ctx["prop_id"] == ".":
             raise PreventUpdate
 
@@ -397,7 +398,6 @@ def update_intersection(
             "data",
         ),
     )
-    # pylint: disable=too-many-arguments: disable=too-many-branches, too-many-locals
     def _update_apply_button(
         _apply_click: Optional[int],
         surfaceattribute: str,
@@ -410,7 +410,7 @@ def update_intersection(
         previous_settings: Dict,
     ) -> Tuple[Dict, Dict]:
 
-        ctx = dash.callback_context.triggered[0]
+        ctx = callback_context.triggered[0]
 
         new_settings = {
             "surface_attribute": surfaceattribute,
