@@ -1,22 +1,20 @@
-from typing import Dict, List
-from pathlib import Path
 import json
+from pathlib import Path
+from typing import Dict, List
 
-import dash
-from dash.dependencies import Input, Output, ALL
-import dash_html_components as html
-from webviz_config import WebvizPluginABC, WebvizSettings
 import webviz_core_components as wcc
+from dash import ALL, Dash, Input, Output, callback_context, html
+from webviz_config import WebvizPluginABC, WebvizSettings
 
-from webviz_subsurface._providers import EnsembleTableProviderFactory
 from webviz_subsurface._components.tornado.tornado_widget import TornadoWidget
 from webviz_subsurface._datainput.fmu_input import find_sens_type
+from webviz_subsurface._providers import EnsembleTableProviderFactory
 
 
 class TornadoPlotterFMU(WebvizPluginABC):
     """General tornado plotter for FMU data from a csv file of responses.
     ---
-    * **`ensembles`:** Which ensembles in `shared_settings` to visualize.
+    * **`ensemble`:** Which ensemble in `shared_settings` to visualize.
     * **`csvfile`:** Relative ensemble path to csv file with responses
     * **`aggregated_csvfile`:** Alternative to ensemble + csvfile with
     aggregated responses. Requires REAL and ENSEMBLE columns
@@ -37,10 +35,10 @@ class TornadoPlotterFMU(WebvizPluginABC):
     REGIONS.
     """
 
-    # pylint: disable=too-many-locals, too-many-arguments
+    # pylint: disable=too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile: str = None,
         ensemble: str = None,
@@ -218,7 +216,7 @@ class TornadoPlotterFMU(WebvizPluginABC):
             ]
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self._tornado_widget.storage_id, "data"),
             Input(self.uuid("response"), "value"),
@@ -243,12 +241,12 @@ class TornadoPlotterFMU(WebvizPluginABC):
             # Filter data
             if single_filters is not None:
                 for value, input_dict in zip(
-                    single_filters, dash.callback_context.inputs_list[1]
+                    single_filters, callback_context.inputs_list[1]
                 ):
                     data = data.loc[data[input_dict["id"]["name"]] == value]
             if multi_filters is not None:
                 for value, input_dict in zip(
-                    multi_filters, dash.callback_context.inputs_list[2]
+                    multi_filters, callback_context.inputs_list[2]
                 ):
                     data = data.loc[data[input_dict["id"]["name"]].isin(value)]
 
